<?php
/*
Plugin Name: Discreet Toolbar
Plugin URI: http://trepmal.com/plugins/discreet-toolbar
Description: Hide Admin Bar till cursor is near it. Front-end only.
Version: 0.4
Author: Kailey Lampert
Author URI: http://kaileylampert.com/
*/

$discreet_toolbar = new Discreet_Toolbar();

class Discreet_Toolbar {

	/**
	 * Hook in (part 1)
	 *
	 * @return void
	 */
	function __construct() {
		add_action( 'init',               array( $this, 'init' ) );
	}

	/**
	 * Hook in (part 2), when Admin Bar is showing
	 *
	 * @return void
	 */
	function init() {
		if ( ! is_admin_bar_showing() ) {
			return;
		}
		add_action( 'wp_enqueue_scripts', array( $this, 'scripts' ) );
		add_action( 'admin_bar_init',     array( $this, 'admin_bar_init' ) );
		add_filter( 'body_class',         array( $this, 'body_class' ), 10, 2 );
	}

	/**
	 * Enqueue scripts
	 *
	 * @return void
	 */
	function scripts() {

		$suffix = defined('SCRIPT_DEBUG') && SCRIPT_DEBUG ? '.dev' : '';
		wp_enqueue_script( 'discreet', plugins_url( "discreet$suffix.js", __FILE__ ), array('jquery'), 1, true );
	}

	/**
	 * Unhook admin bar bumper styles
	 *
	 * @return void
	 */
	function admin_bar_init() {
		remove_action('wp_head',          '_admin_bar_bump_cb' );
	}

	/**
	 * Remove admin-bar class
	 *
	 * @param array $classes An array of body classes.
	 * @param array $class   An array of additional classes added to the body.
	 * @return array
	 */
	function body_class( $classes, $class ) {
		$pos = array_search( 'admin-bar', $classes );
		if ( false !== $pos ) {
			unset( $classes[ $pos ] );
		}
		return $classes;
	}

}